##############################################################################
#
# Copyright (c) 2003 - Tue Wennerberg - All Rights Reserved
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from Globals import Persistent, MessageDialog, HTML
import OFS.SimpleItem, Acquisition
import AccessControl.Role, sys, os, stat, traceback
from OFS.SimpleItem import pretty_tb
from App.Extensions import getObject, getPath, FuncCode
from Globals import DevelopmentMode
from App.Management import Navigation
from ComputedAttribute import ComputedAttribute
from AccessControl import ClassSecurityInfo

from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.PageTemplates import ZopePageTemplate
from Products.ExternalMethod import ExternalMethod
from OFS import Folder

################################################################################

manage_addAdictEventForm=PageTemplateFile('Products/ZAdict/zpt/addEventForm.zpt')

def manage_addAdictEvent(self, id,
                          date, eventseq, days, starttime, endtime, lastedited,
                          authoremail, authorname, currency, price, language,
                          continent, country, city, organizer, organizerurl,
                          eventurl, headline, description, REQUEST=None):
    """Add a Adict Event
    """
    id = str(id)

    # Create new object instance
    newobj = AdictEvent(id, date, eventseq, days,starttime,endtime,lastedited,
                          authoremail, authorname, currency, price, language,
                          continent, country, city, organizer, organizerurl,
                          eventurl, headline, description)
    
    # Add to current container
    self._setObject(id, newobj)

    if REQUEST is not None:
        return self.manage_main(self,REQUEST)

################################################################################

class AdictEvent(OFS.SimpleItem.Item, Persistent, Acquisition.Explicit,
                     AccessControl.Role.RoleManager, Navigation):

    meta_type = 'Adict Event'
    """
    Adict Event
    """

    def __init__(self, id, date,eventseq, days, starttime, endtime, lastedited,
                 authoremail, authorname, currency, price, language, continent,
                 country, city, organizer,organizerurl, eventurl, headline,
                 description):

        self.id = id
        self.manage_edit(date, eventseq, days, starttime, endtime, lastedited,
                         authoremail, authorname, currency, price, language,
                         continent, country, city, organizer, organizerurl,
                         eventurl, headline, description)

    ZopeTime=Acquisition.Acquired
    HelpSys=Acquisition.Acquired
    security = ClassSecurityInfo()

    manage_options = (
        (
            {'label':'Properties', 'action':'manage_main'},
        )
        + OFS.SimpleItem.Item.manage_options
        + AccessControl.Role.RoleManager.manage_options
    )

    __ac_permissions__ = (
        ('View management screens', ('manage_main',)),
        ('View', ('__call__','')),
    )

    manage_main = PageTemplateFile('Products/ZAdict/zpt/editEventForm.zpt')

    def manage_edit(self, date, eventseq, days, starttime, endtime, lastedited,
                    authoremail, authorname, currency, price, language,
                    continent, country, city, organizer,organizerurl,
                    eventurl, headline, description, REQUEST=None):
        """Change the event
        """
        self.title        = str(headline)
        
        self.date         = str(date)
        self.eventseq     = str(eventseq)
        self.days         = str(days)
        self.starttime    = str(starttime)
        self.endtime      = str(endtime)
        self.lastedited   = str(lastedited)
        self.authoremail  = str(authoremail)
        self.authorname   = str(authorname)
        self.currency     = str(currency)
        self.price        = str(price)
        self.language     = str(language)
        self.continent    = str(continent)
        self.country      = str(country)
        self.city         = str(city)
        self.organizer    = str(organizer)
        self.organizerurl = str(organizerurl)
        self.eventurl     = str(eventurl)
        self.headline     = str(headline)
        self.description  = str(description)
 
        if REQUEST:
            message="Event updated."
            return self.manage_main(self,REQUEST,manage_tabs_message=message)

    def eventString(self):
        """Return event as a string
        """
        import string
        str = string.join([self.date, self.eventseq, self.days,
                           self.starttime, self.endtime, self.lastedited,
                           self.authoremail, self.authorname,
                           self.currency, self.price, self.language,
                           self.continent, self.country, self.city,
                           self.organizer,self.organizerurl,
                           self.eventurl, self.headline,
                           self.description], ";" )
        return str

    def sortKey(self):
        """Return a sort key
        """
        mystr = self.date + " " + self.starttime 
        return mystr

    security.declarePublic('test')
    def test(self):
        """Test
        """
        return str(self)
