##############################################################################
#
# Copyright (c) 2003 - Tue Wennerberg - All Rights Reserved
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from Globals import Persistent, MessageDialog, HTML
import OFS.SimpleItem, Acquisition
import AccessControl.Role, sys, os, stat, traceback
from OFS.SimpleItem import pretty_tb
from App.Extensions import getObject, getPath, FuncCode
from Globals import DevelopmentMode
from App.Management import Navigation
from ComputedAttribute import ComputedAttribute
from AccessControl import ClassSecurityInfo

from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.PageTemplates import ZopePageTemplate
from Products.ExternalMethod import ExternalMethod
from OFS import Folder

import AdictEvent

################################################################################

manage_addAdictSourceForm=PageTemplateFile('Products/ZAdict/zpt/addSourceForm.zpt')

def manage_addAdictSource(self, id, title='',localevents_url='', 
                           site_url='', site_admin='',
                           REQUEST=None):
    """Add a Adict Source
    """
    id = str(id)

    # Create new object instance
    newobj = AdictSource(id, title, localevents_url, site_url, site_admin)
    
    # Add to current container
    self._setObject(id, newobj)

    if REQUEST is not None:
        return self.manage_main(self,REQUEST)


################################################################################

class AdictSource(OFS.SimpleItem.Item, Persistent, Acquisition.Explicit,
                     AccessControl.Role.RoleManager, Navigation):

    meta_type = 'Adict Source'
    """
    Adict Source
    """

    def __init__(self, id, title,localevents_url,site_url,site_admin):
        self.id = id
        self.manage_edit(title, localevents_url, site_url, site_admin)

    ZopeTime = Acquisition.Acquired
    HelpSys  = Acquisition.Acquired
    security = ClassSecurityInfo()

    manage_options = (
        (
            {'label':'Properties', 'action':'manage_main'},
        )
        + OFS.SimpleItem.Item.manage_options
        + AccessControl.Role.RoleManager.manage_options
    )

    __ac_permissions__ = (
        ('View management screens', ('manage_main',)),
        ('View', ('__call__','')),
    )

    manage_main = PageTemplateFile('Products/ZAdict/zpt/editSourceForm.zpt')
    def manage_edit(self, title, localevents_url, site_url, site_admin,
                    REQUEST=None):
        """Change the event source
        """
        self.title           = str(title)
        self.localevents_url = str(localevents_url)
        self.site_url        = str(site_url)
        self.site_admin      = str(site_admin)
 
        if REQUEST:
            message="Event Source updated."
            return self.manage_main(self,REQUEST,manage_tabs_message=message)

    security.declarePublic('suckEvents')
    def suckEvents(self):
        """Suck events from event source
        """
        from urllib import urlopen
        from sys import stderr
        import string, random
        print '--------- Sucking from %s ----------\n' % self.localevents_url
        url = urlopen(self.localevents_url)
        linecount = 0
        line = url.readline()
        newobjects = []
        #while line and linecount < 10:
        while line:
            if line.startswith("DATE;EVENTSEQ;DAYS;STARTTIME;ENDTIME"):
                line = url.readline()
                continue
            f = string.split(line, ';')
            if len(f) == 19:
                id = "Event" + str(random.randrange(1, 1000000))
                newobj = AdictEvent.AdictEvent(id,
                                     f[0], f[1], f[2], f[3], f[4],
                                     f[5], f[6], f[7], f[8], f[9], 
                                     f[10], f[11], f[12], f[13],
                                     f[14], f[15], f[16], f[17], f[18])

                newobjects.append(newobj)
                    
                # Add to current container
                #self.aq_parent.suckedevents._setObject(id, newobj)
            
            linecount = linecount + 1
            line = url.readline()
        return newobjects
        
